absorbing_centrality.compute_fundamental_matrix — absorbing-centrality documentation

# absorbing_centrality.compute_fundamental_matrix

`compute_fundamental_matrix`(P, fast=True, drop_tol=1e-05, fill_factor=1000)

  Computes the fundamental matrix for an absorbing random walk.

  Parameters: | P (scipy.sparse matrix) – The transition probability matrix of the absorbing random walk. To construct this matrix, you start from the original transition matrix and delete the rows that correspond to the absorbing nodes. fast (bool, optional) – True (default), use the iterative SuperLU solver from (If) – scipy.sparse.linalg. – drop_tol (float, optional) – If fast is True, the drop_tol parameter of the SuperLU solver is set to this value (default is 1e-5). fill_factor (int, optional) – If If `fast is True, the fill_factor parameter of the SuperLU solver is set to this value (default is 1000).
  Returns: | F – The fundamental matrix of the random walk. Element (i,j) holds the expected number of times the random walk will be in state j before absorption, when it starts from state i. For more information, check [1].
  Return type: | scipy.sparse matrix

  References

  [1] | Doyle, Peter G., and J. Laurie Snell. Random walks and electric networks. Carus mathematical monographs 22 (2000). https://math.dartmouth.edu/~doyle/docs/walks/walks.pdf